from django.db import models
from treebeard.ns_tree import NS_Node
from urlparse import urljoin, urlsplit
import settings

IMAGE_PLACEMENT_CHOICES = (
	('TL', 'Top Left'),
	('TR', 'Top Right')
)

class Page(NS_Node):
	section = models.ForeignKey('Section')
	template = models.FilePathField(path=settings.SITE_ROOT + '/templates/page_templates', recursive=True, max_length = 255, blank=True)
	name = models.CharField(max_length=100)
	headline = models.CharField(max_length=100)
	content = models.TextField(blank=True)
	image = models.ImageField(blank=True, upload_to='pages/images')
	image_placement = models.CharField(max_length=2, choices=IMAGE_PLACEMENT_CHOICES)
	image_enlargeable = models.BooleanField()
	show_navigation = models.BooleanField()
	slug = models.SlugField(blank=False)
	is_stub = models.BooleanField()
	url = models.CharField(max_length=100, editable=False)
	last_update = models.DateTimeField(auto_now=True)

	class Meta:
		ordering = ['tree_id', 'lft']

	def __unicode__(self):
		return self.name

	def get_absolute_url(self):
		return self.url

	def save(self, *args, **kwargs):
		# find the parent node(s) and use them to build a URL for this item 
		# this is pre-calculated since it's slightly database-heavy and should
		# change very infrequently
		baseurl = urlsplit(settings.BASE_URL)
		self.url = urljoin(baseurl.path, self.section.slug + u'/')
		ancestors = self.get_ancestors()
		for ancestor in ancestors:
			self.url = urljoin(self.url, ancestor.slug + u'/') 
		self.url = urljoin(self.url,self.slug + u'/')
		super(Page, self).save(*args, **kwargs)


class Section(models.Model):
	name = models.CharField(max_length=100, blank=False)
	slug = models.SlugField(blank=False)

	class Meta:
		verbose_name = "Section"
		verbose_name_plural = "Sections"
	
	def __unicode__(self):
		return self.name

	def get_absolute_url(self):
		return settings.BASE_URL + self.slug + '/'
